<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>LXQtModuleManager</name>
    <message>
        <location filename="../src/lxqtmodman.cpp" line="347"/>
        <source>Crash Report</source>
        <translation>崩溃报告</translation>
    </message>
    <message>
        <location filename="../src/lxqtmodman.cpp" line="348"/>
        <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; 多次崩溃，直至下一次登录前都不会再自动重新启动该程序。</translation>
    </message>
</context>
<context>
    <name>SessionApplication</name>
    <message>
        <location filename="../src/main.cpp" line="62"/>
        <source>Configuration file path.</source>
        <translation>配置文件路径。</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="62"/>
        <location filename="../src/main.cpp" line="63"/>
        <source>file</source>
        <translation>文件</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="63"/>
        <source>Window manager to use.</source>
        <translation>要使用的窗口管理器。</translation>
    </message>
    <message>
        <location filename="../src/sessionapplication.cpp" line="89"/>
        <source>DBus Environment</source>
        <translation>DBus 环境</translation>
    </message>
    <message>
        <location filename="../src/sessionapplication.cpp" line="90"/>
        <source>The DBus Activation Environment wasn&apos;t updated. Some apps might not work properly</source>
        <translation>DBus 激活环境没有更新。某些应用程序可能无法正常工作</translation>
    </message>
</context>
<context>
    <name>WmSelectDialog</name>
    <message>
        <location filename="../src/wmselectdialog.ui" line="14"/>
        <source>Welcome to LXQt</source>
        <translation>欢迎使用 LXQt</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.cpp" line="65"/>
        <source>Other ...</source>
        <translation>其他...</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.cpp" line="66"/>
        <source>Choose your favorite one.</source>
        <translation>选择您最喜欢的一个。</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Welcome to LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Please select your default Window Manager.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;欢迎使用 LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;请选择您的默认窗口管理器。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.ui" line="71"/>
        <source>You will be able to change this at any time through Preferences -&gt; Session Settings -&gt; Basic Settings.</source>
        <translation>您可以随时在 首选项 -&gt; 会话配置 -&gt; 基本设置 中更改此设置。</translation>
    </message>
</context>
</TS>
